@@ -167,7 +167,7 @@ toc_try_dispose (GObject *object)
     g_assert (object != NULL && YELP_IS_TOC (object));
 
     priv = YELP_TOC (object)->priv;
-
+    
     g_mutex_lock (priv->mutex);
     if (priv->process_running || priv->transform_running) {
 	priv->state = TOC_STATE_STOP;
@@ -184,6 +184,7 @@ toc_dispose (GObject *object)
 {
     YelpToc *toc = YELP_TOC (object);
 
+    toc_doc = NULL;
     if (toc->priv->xmldoc)
 	xmlFreeDoc (toc->priv->xmldoc);
 
@@ -288,7 +289,6 @@ transform_func (YelpTransform       *transform,
     g_assert (toc != NULL && YELP_IS_TOC (toc));
 
     priv = toc->priv;
-
     g_assert (transform == priv->transform);
 
     if (priv->state == TOC_STATE_STOP) {
@@ -305,6 +305,7 @@ transform_func (YelpTransform       *transform,
 	yelp_transform_release (transform);
 	priv->transform = NULL;
 	priv->transform_running = FALSE;
+	priv->process_running = FALSE;
 	return;
     }
 
@@ -317,6 +318,7 @@ transform_func (YelpTransform       *transform,
 	yelp_transform_release (transform);
 	priv->transform = NULL;
 	priv->transform_running = FALSE;
+	priv->process_running = FALSE;
 	break;
     case YELP_TRANSFORM_FINAL:
 	transform_final_func (transform, toc);
@@ -362,12 +364,14 @@ transform_final_func (YelpTransform *transform, YelpToc *toc)
 
     error = yelp_error_new (_("Page not found"),
 			    _("The requested page was not found in the TOC."));
-    yelp_document_error_pending (YELP_DOCUMENT (toc), error);
+    yelp_document_final_pending (YELP_DOCUMENT (toc), error);
 
     yelp_transform_release (priv->transform);
     priv->transform = NULL;
 
     priv->transform_running = FALSE;
+    priv->process_running = FALSE;
+    priv->state = TOC_STATE_PARSED;
 
     if (priv->xmldoc) {
 	xmlFreeDoc (priv->xmldoc);
@@ -446,6 +450,8 @@ toc_process (YelpToc *toc)
 	xmlChar *icon = NULL;
 	xmlChar *id = NULL;
 
+	xmlNodeSetLang (node, BAD_CAST g_get_language_names ()[0]);
+
 	xml_trim_titles (node, BAD_CAST "title");
 	xml_trim_titles (node, BAD_CAST "description");
 
@@ -498,10 +504,10 @@ toc_process (YelpToc *toc)
 
     info = gtk_icon_theme_lookup_icon (theme, "yelp-icon-big", 192, 0);
     if (info) {
-	params[params_i++] = "help_icon";
+	params[params_i++] = g_strdup ("help_icon");
 	params[params_i++] = g_strdup_printf ("\"%s\"",
 				      gtk_icon_info_get_filename (info));
-	params[params_i++] = "help_icon_size";
+	params[params_i++] = g_strdup ("help_icon_size");
 	params[params_i++] = g_strdup_printf ("%i",
 					      gtk_icon_info_get_base_size (info));
 	gtk_icon_info_free (info);
@@ -523,6 +529,7 @@ toc_process (YelpToc *toc)
     yelp_transform_start (priv->transform,
 			  priv->xmldoc,
 			  params);
+    g_strfreev (params);
     g_mutex_unlock (priv->mutex);
 
  done:
